package com.ruoyi.board.service.impl;

import com.github.yulichang.base.MPJBaseServiceImpl;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import com.ruoyi.board.domain.BoardInfo;
import com.ruoyi.board.domain.BoardProtocol;
import com.ruoyi.board.domain.BoardType;
import com.ruoyi.board.domain.RoadGroup;
import com.ruoyi.board.domain.dto.BoardInfoAndRoadDTO;
import com.ruoyi.board.mapper.BoardInfoMapper;
import com.ruoyi.board.service.IBoardInfoService;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class BoardInfoServiceImpl extends MPJBaseServiceImpl<BoardInfoMapper, BoardInfo> implements IBoardInfoService {

    @Override
    public BoardInfoAndRoadDTO getOneByIP(String ip) {
        MPJLambdaWrapper<BoardInfo> eq = condition()
                .eq(StringUtils.isNotEmpty(ip), BoardInfo::getBoardIp, ip);
        return selectJoinOne(BoardInfoAndRoadDTO.class, eq);
    }

    @Override
    public List<BoardInfoAndRoadDTO> listBoardInfoDTO(BoardInfo boardInfo) {
        MPJLambdaWrapper<BoardInfo> eq = condition()
                .likeRight(StringUtils.isNotEmpty(boardInfo.getBoardName()), BoardInfo::getBoardName, boardInfo.getBoardName())
                .likeRight(StringUtils.isNotEmpty(boardInfo.getBoardMileage()), BoardInfo::getBoardMileage, boardInfo.getBoardMileage())
                .eq(StringUtils.isNotEmpty(boardInfo.getBoardRoadSection()), BoardInfo::getBoardRoadSection, boardInfo.getBoardRoadSection());
        return selectJoinList(BoardInfoAndRoadDTO.class, eq);
    }


    private MPJLambdaWrapper<BoardInfo> condition() {
        return new MPJLambdaWrapper<BoardInfo>()
                .selectAll(BoardInfo.class)
                .select(RoadGroup::getRoadName)
                .selectAs(BoardType::getName, "board_size_name")
                .selectAs(BoardType::getSize, "board_size")
                .selectAs(BoardProtocol::getBrand, "board_brand_name")
                .selectAs(BoardProtocol::getProtocol, "board_protocol_name")
                .leftJoin(RoadGroup.class, RoadGroup::getId, BoardInfo::getBoardRoadSection)
                .leftJoin(BoardType.class, BoardType::getId, BoardInfo::getBoardSizeType)
                .leftJoin(BoardProtocol.class, BoardProtocol::getId, BoardInfo::getBoardBrandProtocol);
    }
}
